==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/WindowsAppXAppAssignmentSettings.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Optional;


/**
 * <i>“Contains properties used when assigning a Windows AppX mobile app to a group.”</i>
 */@JsonPropertyOrder({
    "@odata.type", 
    "useDeviceContext"})
@JsonInclude(Include.NON_NULL)
public class WindowsAppXAppAssignmentSettings extends MobileAppAssignmentSettings implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    @JsonProperty("useDeviceContext")
    protected Boolean useDeviceContext;

    protected WindowsAppXAppAssignmentSettings() {
        super();
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.windowsAppXAppAssignmentSettings";
    }

    /**
     * <i>“Whether or not to use device execution context for Windows AppX mobile app.”</i>
     * 
     * @return property useDeviceContext
     */
    @Property(name="useDeviceContext")
    @JsonIgnore
    public Optional<Boolean> getUseDeviceContext() {
        return Optional.ofNullable(useDeviceContext);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code useDeviceContext}
     * field changed. Field description below. The field name is also added to an
     * internal map of changed fields in the returned object so that when {@code this.
     * patch()} is called (if available)on the returned object only the changed fields
     * are submitted.
     * <p>
     * <i>“Whether or not to use device execution context for Windows AppX mobile app.”</i>
     * 
     * @param useDeviceContext
     *            new value of {@code useDeviceContext} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code useDeviceContext} field changed
     */
    public WindowsAppXAppAssignmentSettings withUseDeviceContext(Boolean useDeviceContext) {
        WindowsAppXAppAssignmentSettings _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.windowsAppXAppAssignmentSettings");
        _x.useDeviceContext = useDeviceContext;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderWindowsAppXAppAssignmentSettings() {
        return new Builder();
    }

    public static final class Builder {
        private Boolean useDeviceContext;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        /**
         * <i>“Whether or not to use device execution context for Windows AppX mobile app.”</i>
         * 
         * @param useDeviceContext
         *            value of {@code useDeviceContext} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder useDeviceContext(Boolean useDeviceContext) {
            this.useDeviceContext = useDeviceContext;
            this.changedFields = changedFields.add("useDeviceContext");
            return this;
        }

        public WindowsAppXAppAssignmentSettings build() {
            WindowsAppXAppAssignmentSettings _x = new WindowsAppXAppAssignmentSettings();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.windowsAppXAppAssignmentSettings";
            _x.useDeviceContext = useDeviceContext;
            return _x;
        }
    }

    private WindowsAppXAppAssignmentSettings _copy() {
        WindowsAppXAppAssignmentSettings _x = new WindowsAppXAppAssignmentSettings();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.useDeviceContext = useDeviceContext;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("WindowsAppXAppAssignmentSettings[");
        b.append("useDeviceContext=");
        b.append(this.useDeviceContext);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/complex/WindowsAppXAppAssignmentSettings.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Boolean;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;


/**
 * <i>“Contains properties used when assigning a Windows AppX mobile app to a group.”</i>
 */@JsonPropertyOrder({
    "@odata.type", 
    "useDeviceContext"})
@JsonInclude(Include.NON_NULL)
public class WindowsAppXAppAssignmentSettings extends MobileAppAssignmentSettings implements ODataType {

    @JsonProperty("useDeviceContext")
    protected Boolean useDeviceContext;

    protected WindowsAppXAppAssignmentSettings() {
        super();
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.windowsAppXAppAssignmentSettings";
    }

    /**
     * <i>“Whether or not to use device execution context for Windows AppX mobile app.”</i>
     * 
     * @return property useDeviceContext
     */
    @Property(name="useDeviceContext")
    @JsonIgnore
    public Optional<Boolean> getUseDeviceContext() {
        return Optional.ofNullable(useDeviceContext);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code useDeviceContext}
     * field changed. Field description below. The field name is also added to an
     * internal map of changed fields in the returned object so that when {@code this.
     * patch()} is called (if available)on the returned object only the changed fields
     * are submitted.
     * <p>
     * <i>“Whether or not to use device execution context for Windows AppX mobile app.”</i>
     * 
     * @param useDeviceContext
     *            new value of {@code useDeviceContext} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code useDeviceContext} field changed
     */
    public WindowsAppXAppAssignmentSettings withUseDeviceContext(Boolean useDeviceContext) {
        WindowsAppXAppAssignmentSettings _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.windowsAppXAppAssignmentSettings");
        _x.useDeviceContext = useDeviceContext;
        return _x;
    }

    public WindowsAppXAppAssignmentSettings withUnmappedField(String name, Object value) {
        WindowsAppXAppAssignmentSettings _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderWindowsAppXAppAssignmentSettings() {
        return new Builder();
    }

    public static final class Builder {
        private Boolean useDeviceContext;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        /**
         * <i>“Whether or not to use device execution context for Windows AppX mobile app.”</i>
         * 
         * @param useDeviceContext
         *            value of {@code useDeviceContext} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder useDeviceContext(Boolean useDeviceContext) {
            this.useDeviceContext = useDeviceContext;
            this.changedFields = changedFields.add("useDeviceContext");
            return this;
        }

        public WindowsAppXAppAssignmentSettings build() {
            WindowsAppXAppAssignmentSettings _x = new WindowsAppXAppAssignmentSettings();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.windowsAppXAppAssignmentSettings";
            _x.useDeviceContext = useDeviceContext;
            return _x;
        }
    }

    private WindowsAppXAppAssignmentSettings _copy() {
        WindowsAppXAppAssignmentSettings _x = new WindowsAppXAppAssignmentSettings();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.useDeviceContext = useDeviceContext;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("WindowsAppXAppAssignmentSettings[");
        b.append("useDeviceContext=");
        b.append(this.useDeviceContext);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
